pub struct InfoGraphDot<'graph> {
pub graph_style: GraphStyle,
pub node_id_to_hierarchy: &'graph HashMap<&'graph NodeId, &'graph NodeHierarchy>,
pub node_ids: Vec<&'graph NodeId>,
pub edge_ids: Vec<&'graph EdgeId>,
}Fields
graph_style: GraphStylenode_id_to_hierarchy: &'graph HashMap<&'graph NodeId, &'graph NodeHierarchy>node_ids: Vec<&'graph NodeId>edge_ids: Vec<&'graph EdgeId>Trait Implementations
Sourceimpl<'graph> Clone for InfoGraphDot<'graph>
impl<'graph> Clone for InfoGraphDot<'graph>
Sourcefn clone(&self) -> InfoGraphDot<'graph>
fn clone(&self) -> InfoGraphDot<'graph>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Themeable for InfoGraphDot<'_>
impl Themeable for InfoGraphDot<'_>
Sourcefn node_ids(&self) -> impl Iterator<Item = &NodeId>where
Self: Sized,
fn node_ids(&self) -> impl Iterator<Item = &NodeId>where
Self: Sized,
Returns the IDs of all nodes of this themeable type.
Sourcefn node_outline_classes(
&self,
node_id: &AnyId,
builder: &mut CssClassesBuilder<'_>,
line_params: LineParams<'_>,
)
fn node_outline_classes( &self, node_id: &AnyId, builder: &mut CssClassesBuilder<'_>, line_params: LineParams<'_>, )
Appends the CSS classes that sets the outline colour and style. Read more
Sourcefn node_stroke_classes(
&self,
node_id: &AnyId,
builder: &mut CssClassesBuilder<'_>,
line_params: LineParams<'_>,
)
fn node_stroke_classes( &self, node_id: &AnyId, builder: &mut CssClassesBuilder<'_>, line_params: LineParams<'_>, )
Appends the CSS classes that sets the line / border colour and style. Read more
Sourcefn node_fill_classes(
&self,
node_id: &AnyId,
builder: &mut CssClassesBuilder<'_>,
color_params: ColorParams<'_>,
)
fn node_fill_classes( &self, node_id: &AnyId, builder: &mut CssClassesBuilder<'_>, color_params: ColorParams<'_>, )
Appends the CSS classes that sets the background colour and style. Read more
Sourcefn edge_ids(&self) -> impl Iterator<Item = &EdgeId>where
Self: Sized,
fn edge_ids(&self) -> impl Iterator<Item = &EdgeId>where
Self: Sized,
Returns the IDs of all edges of this themeable type.
Sourcefn edge_outline_classes(
&self,
_edge_id: &AnyId,
builder: &mut CssClassesBuilder<'_>,
line_params: LineParams<'_>,
)
fn edge_outline_classes( &self, _edge_id: &AnyId, builder: &mut CssClassesBuilder<'_>, line_params: LineParams<'_>, )
Appends the CSS classes that sets the outline colour and style. Read more
Sourcefn edge_stroke_classes(
&self,
_edge_id: &AnyId,
builder: &mut CssClassesBuilder<'_>,
line_params: LineParams<'_>,
)
fn edge_stroke_classes( &self, _edge_id: &AnyId, builder: &mut CssClassesBuilder<'_>, line_params: LineParams<'_>, )
Appends the CSS classes that sets the stroke colour and style. Read more
Sourcefn edge_fill_classes(
&self,
_edge_id: &AnyId,
builder: &mut CssClassesBuilder<'_>,
color_params: ColorParams<'_>,
)
fn edge_fill_classes( &self, _edge_id: &AnyId, builder: &mut CssClassesBuilder<'_>, color_params: ColorParams<'_>, )
Appends the CSS classes that sets the background colour and style. Read more